@@ -1,19 +1,21 @@
-( cd opt/httpd-2.2.11/modules ; rm -rf libphp5.so )
-( cd opt/httpd-2.2.11/modules ; ln -sf libphp5.so.5.2.8 libphp5.so )
-#%% begin initialize 01_php-5.2.8_0.9.6.3-i586-P2
+( cd  opt/httpd/modules/ && rm -f libphp5.so )
+( cd  opt/httpd/modules/ && ln -sf libphp5.so.5.2.10 libphp5.so )
+( if [ -d opt/php5 ]; then mv opt/php5 opt/php5.bak; fi )
+( cd  opt && rm -f php5 && ln -sf php-5.2.10  php5 )
+#%% begin initialize /01_php-5.2.10-i586-P2
 #!/bin/sh 
 #
 # This should be done at initial booting after installation.
 # requires:
-#	httpd-2.2.11
+#	httpd-2.2.12
 #
 export PATH=/bin:/usr/bin:/sbin:/usr/sbin
 export LANG=C
 
-
-VERSION=5.2.8
-PREFIX=/opt/php5
-CONFIG=/opt/php5/etc
+VERSION=5.2.10
+#PREFIX=/opt/php5
+PREFIX=/opt/php-$VERSION
+CONFIG=/opt/php-5.2.10/etc
 HTTPDIR=/opt/httpd
 HTDOCS=/opt/htdocs
 
@@ -54,6 +56,7 @@ fi
   /bin/chmod -R go-w,go+rX  $ROOT/$PREFIX/lib/php
 
 
+
 # Restart Apache Web Server
 if [ "$ROOT" = "" ]; then
   $ROOT/$HTTPDIR/bin/apachectl stop
