@@ -1,17 +1,21 @@
 #!/bin/bash
 # PHP-5.2	(http://www.php.net)
-#	BuildScript for Plamo Linux 4.5
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2008-06-30
+#	BuildScript for Plamo Linux 4.6
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2009-08-01
 # require:
-HTTPD_VER=2.2.9
+HTTPD_VER=2.2.12
 HTTPD=httpd-$HTTPD_VER
 #	postgresql-8.3.x
 #	re2c-0.12.2
 #PHP
-VERSION=5.2.6
+VERSION=5.2.10
+#VERSION=5.2.7RC4
 #SUHOSIN
+# ex. http://download.suhosin.org/suhosin-0.9.27.tgz
+SUHOSIN=suhosin-0.9.27
+# ex. http://download.suhosin.org/suhosin-patch-5.2.7-0.9.6.3.patch.gz
 PAT_VER=
-#PAT_VER=0.9.6.2
+#PAT_VER=0.9.6.3
 DOC_ONLY=
 DOC_ONLY=-1	# -1: php binary package only
 #DOC_ONLY=1	# 1: document package only
@@ -24,8 +28,12 @@ fi
 PAC_NAME=php-${VERSION}
 SRC_FILE=${PAC_NAME}.tar.gz
 SRC_URI="http://jp.php.net/get/$SRC_FILE/from/this/mirror"
-PAT_FILE=suhosin-patch-${VERSION}-${PAT_VER}.patch.gz
-PAT_URI="http://www.hardened-php.net/suhosin/_media/$PAT_FILE"
+#SRC_URI=http://downloads.php.net/ilia/$SRC_FILE
+
+if [ "$PAT_VER" != "" ]; then
+  PAT_FILE=suhosin-patch-${VERSION}-${PAT_VER}.patch.gz
+  PAT_URI="http://download.suhosin.org//$PAT_FILE"
+fi
 #MBPAT_FILE=mbstring-jpr-25298-20050414.patch.diff.gz
 #MBPAT_URI=http://www.voltex.jp/patches/$MBPAT_FILE
 
@@ -35,15 +43,17 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/www/php
-PAC_DIR=$PLAMO/Packages/4.5/WWW
+PAC_DIR=$PLAMO/Packages/4.6/09_webdb/03_PHP.tgz/
 BUILD_DIR=$PLAMO/php52
 CUSTOM_DIR=$BUILD_DIR/Custom
-CUSTOM_PAT=php-5.2.6-strict-session.patch
+# patch the following if suhosin patch is not applied.
+#CUSTOM_PAT=php-5.2.6-strict-session.patch
 # http://wiki.ohgaki.net/index.php?plugin=attach&refer=PHP%2Fpatch%2FStrictSession&openfile=php-5.2.6-strict-session.patch
 # which include http://www.suspekt.org/session_strict_mode.patch
 
 #PREFIX=usr
-PREFIX=opt/php5
+PREFIX=opt/$PAC_NAME
+#DESTDIR=opt/$PAC_NAME
 #CONFIG=etc
 CONFIG=$PREFIX/etc
 
@@ -61,7 +71,7 @@ if [ ! -f $SRC_DIR/$SRC_FILE ]; then
 fi
 if [ "x$PAT_VER" != "x" ]; then
   if [ ! -f $SRC_DIR/$PAT_FILE ]; then
-    (cd $SRC_DIR; wget $PAT_URI);
+    (cd $SRC_DIR; wget -N $PAT_URI);
   fi
 fi
 
@@ -70,6 +80,13 @@ DOC_FILE=php_manual_ja.tar.gz
 DOC_URI="http://jp.php.net/get/$DOC_FILE/from/this/mirror"
 
 
+if [ "x$PAT_VER" = "x" ]; then
+  PACKAGE=01_${PAC_NAME}-${SYS_NAME}
+else
+  PACKAGE=01_${PAC_NAME}_${PAT_VER}-${SYS_NAME}
+fi
+
+
 umask 022
 CWD=`pwd`
 WORK=$CWD/work
@@ -78,7 +95,7 @@ mkdir -p $WORK
 export LANG=C
 export LC_ALL=C
 export CFLAGS="-O2 -march=$CPU"
-export PATH=$PATH:/usr/X11R7/bin
+export PATH=$PATH:/usr/X11R7/bin:/$PREFIX/bin
 
 
 if [ "$DOC_ONLY" != "1" ]; then
@@ -92,15 +109,20 @@ if [ -d $PAC_NAME ]; then
  rm -rf ${PAC_NAME}/doc-pak/
 fi
 
-tar xvfz $SRC_DIR/$SRC_FILE
-# exit
-cd ${PAC_NAME}
-if [ "x$PAT_VER" != "x" ]; then
-  zcat $SRC_DIR/$PAT_FILE | patch -p1
-fi
-if [ -f $CUSTOM_DIR/$CUSTOM_PAT ]; then
-  cat $CUSTOM_DIR/$CUSTOM_PAT | patch -p1
+if [ ! -d $PAC_NAME ]; then
+ tar xvfz $SRC_DIR/$SRC_FILE
+ # exit
+ cd ${PAC_NAME}
+ if [ "x$PAT_VER" != "x" ]; then
+   zcat $SRC_DIR/$PAT_FILE | patch -p1
+ fi
+ if [ -f $CUSTOM_DIR/$CUSTOM_PAT ]; then
+   cat $CUSTOM_DIR/$CUSTOM_PAT | patch -p1
+ fi
+else
+ cd ${PAC_NAME}
 fi
+
 #	if `false`; then
 ./configure  --prefix=/$PREFIX --with-config-file-path=/$CONFIG \
   --with-apxs2=/opt/httpd/bin/apxs --with-pear \
@@ -113,18 +135,19 @@ fi
 
   #--with-config-file-scan-dir
 
-rm -rf doc-pak
 make
-
 mv /opt/httpd/conf/httpd.conf /opt/httpd/conf/httpd.conf.orig
-chkinstall -P -y > inst.log
-rm -f /var/log/packages/php
+mv /opt/httpd/modules/libphp5.so /opt/httpd/modules/libphp5.so.orig
+make install
 mv /opt/httpd/conf/httpd.conf.orig /opt/httpd/conf/httpd.conf
 
 mkdir -p $WORK/opt/htdocs
 
 export PATH=/$PREFIX/bin:$PATH
 
+rm -rf /$PREFIX/lib/php/.channels/
+pear upgrade
+
 pear install --alldeps DB
 pear install --alldeps Auth
 pear install --alldeps Auth_SASL
@@ -133,7 +156,7 @@ pear install --alldeps HTML_Template_IT
 pear install --alldeps HTML_QuickForm HTML_QuickForm_Controller
 #pear install XML_Parser XML_Util Config
 pear install --alldeps Config
-pear install --alldeps DB
+pear install --alldeps MDB2
 pear install --alldeps Mail_Mime
 #pear install Net_Socket HTTP_Request
 pear install --alldeps HTTP_Request
@@ -276,7 +299,7 @@ __EOFmhash
 $ZTS/ncurses.so
 __EOFncurses
 
-# require net-snmp-5.1.1-i386-P1
+# require net-snmp
  cd ../snmp
    phpize
    ./configure
@@ -285,7 +308,7 @@ __EOFncurses
 $ZTS/snmp.so
 __EOFsnmp
 
-# require openldap-2.3.x-i386-P1
+# require openldap
  cd ../ldap
    phpize
    ./configure
@@ -294,7 +317,7 @@ __EOFsnmp
 $ZTS/ldap.so
 __EOFldap
 
-# require imap-2004a-i386-P1
+# require alpine(imap)
  cd ../imap
    phpize
    ./configure --with-imap-ssl=/usr
@@ -429,6 +452,13 @@ $ZTS/apc.so
 __EOFapc
    cd ..
 
+# APD
+ pecl install apd
+ cat >> ../../ext/extpkg.lis<<__EOFapd
+$ZTS/apd.so
+__EOFapd
+
+
 # Namazu
 wget -N http://osdn.dl.sourceforge.jp/php-i18n/14174/namazu-2.3.1.tgz
 tar xvfz namazu-2.3.1.tgz
@@ -442,7 +472,8 @@ __EOFnamazu
 
    cd ..
 
-SUHOSIN=suhosin-0.9.24
+
+if [ "$SUHOSIN" != "" ]; then
 #curl -o $SUHOSIN.tgz http://www.hardened-php.net/suhosin/_media/$SUHOSIN.tgz\?id=download&cache=cache
 wget http://download.suhosin.org/$SUHOSIN.tgz
 tar xvfz $SUHOSIN.tgz
@@ -455,30 +486,51 @@ $ZTS/suhosin.so
 __EOFsuhosin
 
   cd ..
+fi #SUHOSIN
 
-pecl install -f uploadprogress
+# UplaodProgress
+  pecl install -f uploadprogress
+  cat >> ../../ext/extpkg.lis<<__EOFuploadprogress
+$ZTS/uploadprogress.so
+__EOFuploadprogress
 
-  cd ..
+# BCompiler
+  pecl install -f bcompiler
+  cat >> ../../ext/extpkg.lis<<__EOFbcompiler
+$ZTS/bcompiler.so
+__EOFbcompiler
 
-cd $WORK
-
-tar xvfz ../${PAC_NAME}/${PAC_NAME}-i386-1.tgz
+cd ..
+pwd
 
 mkdir -p $WORK/$DOC_DIR
 cp -p $BUILD_DIR/`basename $0`  \
-      CODING_STANDARDS CREDITS EXTENSIONS INSTALL LICENSE UPGRADING \
+      CODING_STANDARDS CREDITS EXTENSIONS INSTALL LICENSE NEWS UPGRADING  \
       README* TODO* \
 	$WORK/$DOC_DIR/
 chown -R root.root $WORK/$DOC_DIR
 chmod -R a+rX $WORK/$DOC_DIR
 
-cp -p /$PREFIX/bin/pear     $WORK/PREFIX/bin/
-cp -p /$PREFIX/bin/peardev  $WORK/PREFIX/bin/
-cp -p /$PREFIX/bin/pecl     $WORK/PREFIX/bin/
-tar cf - -C / ./$PREFIX/lib/php/ | tar xvf -
-chown -R root.root ./$PREFIX/lib/php/
-tar cf - -C / ./$PREFIX/include/php/ | tar xvf -
-chown -R root.root $WORK/PREFIX/include/php/
+mkdir -p $WORK/$PREFIX/bin
+cp -p /$PREFIX/bin/php        $WORK/$PREFIX/bin/
+cp -p /$PREFIX/bin/pear       $WORK/$PREFIX/bin/
+cp -p /$PREFIX/bin/peardev    $WORK/$PREFIX/bin/
+cp -p /$PREFIX/bin/pecl       $WORK/$PREFIX/bin/
+cp -p /$PREFIX/bin/phpize     $WORK/$PREFIX/bin/
+cp -p /$PREFIX/bin/php-config $WORK/$PREFIX/bin/
+mkdir -p $WORK/$PREFIX/man/man1
+cp -p /$PREFIX/man/man1/php.*     $WORK/$PREFIX/man/man1/
+cp -p /$PREFIX/man/man1/php-*     $WORK/$PREFIX/man/man1/
+cp -p /$PREFIX/man/man1/phpize.*  $WORK/$PREFIX/man/man1/
+gzip $WORK/$PREFIX/man/man1/php*
+mkdir -p $WORK/$PREFIX/etc
+cp -p /$PREFIX/etc/pear.conf  $WORK/$PREFIX/etc/
+
+cd $WORK
+tar cf -  -C / ./$PREFIX/lib/php/  |  tar xvf -
+tar cf -  -C / ./$PREFIX/include/php/  |  tar xvf -
+chown -R root.root $WORK/$PREFIX/
+
 XTS=`dirname $ZTS`
 ZVR=`basename $ZTS`
 for i in `ls $XTS`; do \
@@ -489,12 +541,17 @@ done
 rm -f opt/$HTTPD/conf/httpd.* install/*
 mkdir -p opt/$HTTPD/conf/conf.d
 cp $CUSTOM_DIR/httpd.php5-sample.conf opt/$HTTPD/conf/conf.d/
+mkdir -p opt/$HTTPD/modules
+cp -p /opt/$HTTPD/modules/libphp5.so opt/$HTTPD/modules/libphp5.so.$VERSION
+cp -p /opt/$HTTPD/modules/libphp5.so.orig /opt/$HTTPD/modules/libphp5.so
+mkdir -p opt/$HTTPD/man/man1
+cp -p /opt/$HTTPD/man/man1/*.1 opt/$HTTPD/man/man1/
+gzip opt/$HTTPD/man/man1/*.1
 
 cp -av $CUSTOM_DIR/htdocs/* $WORK/opt/htdocs/
 tar xvfz $CUSTOM_DIR/emacssl.tgz -C usr/share
-# wget http://browsers.garykeith.com/stream.asp?PHP_BrowsCapINI
-# mv stream.asp\?PHP_BrowsCapINI $CUSTOM_DIR/php_browscap.ini
-cp $CUSTOM_DIR/php_browscap.ini $WORK/PREFIX/lib/php
+curl -o $CUSTOM_DIR/php_browscap.ini http://browsers.garykeith.com/stream.asp\?PHP_BrowsCapINI
+cp $CUSTOM_DIR/php_browscap.ini $WORK/$PREFIX/lib/php/
 
 mkdir -p $WORK/etc
 cp -a $CUSTOM_DIR/profile.d/ $WORK/etc/
@@ -516,6 +573,7 @@ mkdir -p install/
 sed -e "s/_VERSION_/$VERSION/" \
     -e "s/_HTTPD_VER_/$HTTPD_VER/" \
     -e "s%_CONFIG_%/$CONFIG%" \
+    -e "s%_PACKAGE_%/$PACKAGE%" \
 	$CUSTOM_DIR/doinst.sh > install/doinst.sh
 
 mkdir -p $WORK/opt/htdocs/AppList
@@ -528,13 +586,9 @@ REM	PHP Hypertext Preprocessor Webץߥ󥰳ȯ
 __EOCL__
 
 
-if [ "x$PAT_VER" = "x" ]; then
-  PACKAGE=${PAC_NAME}-${SYS_NAME}
-else
-  PACKAGE=${PAC_NAME}_${PAT_VER}-${SYS_NAME}
-fi
+# Make Package
 tar cvfz ${PACKAGE}.tgz $PREFIX/*/* opt/${HTTPD}/*/* $DOC_DIR usr/share/emacs/site-lisp/*  opt/htdocs/* $CONFIG/php.ini-plamo etc/profile.d/php5.* install/doinst.sh 
-mv -v ${PACKAGE}.tgz $PAC_DIR/
+mv -v ${PACKAGE}.tgz $PAC_DIR
 echo "$PAC_DIR/${PACKAGE}.tgz ... done"
 cd $CWD
  
@@ -551,7 +605,7 @@ fi
 ##
 ## Make Document Package
 ##
-DOCPAC=php_doc_jp-${VERSION}-noname-${REL}
+DOCPAC=php_doc_ja-${VERSION}-noname-${REL}
 LOGF=/tmp/wgetlog$$
 (cd $SRC_DIR; \
  wget -N $DOC_URI > $LOGF 2>&1)
@@ -574,5 +628,5 @@ tar xvfz $SRC_DIR/php_manual_euc.tar.gz -C usr/share/doc/$PAC_NAME/
 
 
 tar cvfz ${DOCPAC}.tgz usr/share/doc/$PAC_NAME/manual-ja/
-mv -v ${DOCPAC}.tgz $PAC_DIR/
+mv -v ${DOCPAC}.tgz $PAC_DIR
 
